from setuptools import setup, find_packages

setup(
    name="gaju_mathlib",  # Unique name
    version="1.0.1",      # Incremented version
    description="A simple math library",
    author="Your Name",
    author_email="your.email@example.com",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


